@@ -24,6 +24,7 @@ import time
 import datetime
 import threading
 import platform
+from collections import namedtuple
 # import multiprocessing
 # sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding="UTF-8")
 # sys.stderr = io.TextIOWrapper(sys.stderr.buffer, encoding="UTF-8")
@@ -40,6 +41,7 @@ from arjuna.tpi.error import TestSelectorNotFoundError
 import codecs
 import sys
 
+LinkedArjunaProject = namedtuple("LinkedArjunaProject", "name, location, ref_conf_editable, ref_conf, data_env_conf_map")
 
 @singleton
 class ArjunaSingleton:
@@ -76,6 +78,8 @@ class ArjunaSingleton:
         self.__allowed_log_contexts = {"default"}
         self.__bmproxy_server = None
 
+        self.__linked_projects = None
+
     def __start_bmproxy(self, config):
         # BrowserMob
         from browsermobproxy import Server
@@ -125,7 +129,7 @@ class ArjunaSingleton:
         if not os.path.exists(d):
             os.makedirs(d)
 
-    def init(self, project_root_dir, cli_config, run_id, *, static_rid):
+    def init(self, project_root_dir, cli_config, run_id, *, static_rid, linked_projects):
         from arjuna.configure.options import ArjunaOptions
         ArjunaOptions.load_desc()
         
@@ -138,9 +142,77 @@ class ArjunaSingleton:
         if not static_rid:
             prefix = "{}-".format(datetime.datetime.now().strftime("%Y.%m.%d-%H.%M.%S.%f")[:-3])
         run_id = "{}{}".format(prefix, run_id)
-        self.__thread_wise_ref_conf_map[threading.currentThread().name] = self.__test_session.init(project_root_dir, cli_config, run_id)
+
+        # Process linked Arjuna projects
+        def get_arjuna_project_path_and_name(fpath):
+            from arjuna.core.utils import file_utils
+            if file_utils.is_absolute_path(fpath):
+                if not file_utils.is_dir(fpath):
+                    if file_utils.is_file(fpath):
+                        raise Exception("Not a directory: {}".format(fpath))
+                return os.path.basename(fpath), os.path.abspath(fpath), os.path.abspath(fpath + "/..")
+            else:
+                fpath = os.path.abspath(os.path.join(project_root_dir, fpath))
+                if not file_utils.is_dir(fpath):
+                    if file_utils.is_file(fpath):
+                        raise Exception("Not a directory: {}".format(fpath))
+                return os.path.basename(fpath), os.path.abspath(fpath), os.path.abspath(fpath + "/..") 
+
+        self.__linked_projects = list()
+        linked_project_dict = dict()
 
         from arjuna.tpi.constant import ArjunaOption
+
+        unique_paths = list()
+        for arjuna_proj_dir in linked_projects:
+            proj_name, proj_path, proj_import_path = get_arjuna_project_path_and_name(arjuna_proj_dir)
+            from arjuna.configure.configurator import TestConfigurator
+            l_proj_configurator = TestConfigurator(proj_path, cli_config, run_id)
+            ref_conf_editable = l_proj_configurator.ref_config
+            ref_conf = self.__test_session._create_config(ref_conf_editable)
+            data_env_conf_map = l_proj_configurator.file_confs
+            #for run_env_conf in [self.__test_session._create_config(econf, name=name) for name, econf in l_proj_configurator.file_confs.items()]:
+            #    data_env_conf_map[run_env_conf.name] = run_env_conf
+            self.__linked_projects.append(LinkedArjunaProject(name=proj_name, location=proj_path, ref_conf=ref_conf, ref_conf_editable=ref_conf_editable, data_env_conf_map=data_env_conf_map))
+            unique_paths.append(proj_import_path)
+        
+        unique_paths = set(unique_paths)
+        for p in unique_paths:
+            sys.path.append(p)
+
+        self.__thread_wise_ref_conf_map[threading.currentThread().name] = self.__test_session.init(project_root_dir, cli_config, run_id, self.__linked_projects)
+
+        def get_src_file_path(src):
+            return os.path.abspath(os.path.join(os.path.dirname(os.path.realpath(__file__)), src))
+
+        def get_proj_target_path(dest):
+            return os.path.join(self.ref_config.value(ArjunaOption.PROJECT_ROOT_DIR), dest)
+
+        def copy_file(src, dest):
+            shutil.copyfile(get_src_file_path(src), get_proj_target_path(dest))
+
+        res_import_block = '''
+try:
+    from {project}.lib.resource import *
+except ModuleNotFoundError as e:
+    if e.name not in {{"{project}.lib", "{project}.lib.resource"}}:
+        raise Exception(e.name)
+'''
+
+        from arjuna import Arjuna
+
+        f = open(get_src_file_path("../../res/conftest.txt"), "r")
+        contents = f.read()
+        f.close()
+        res_import_blocks = list()
+        for proj in self.__linked_projects:
+            res_import_blocks.append(res_import_block.format(project=proj.name))
+        res_import_blocks.append(res_import_block.format(project=self.ref_config.value(ArjunaOption.PROJECT_NAME)))
+        contents = contents.format(res_import_block="".join(res_import_blocks))
+        f = open(get_proj_target_path("test/conftest.py"), "w")
+        f.write(contents)
+        f.close()
+
         self.__create_dir_if_doesnot_exist(self.ref_config.value(ArjunaOption.REPORT_DIR))
         self.__create_dir_if_doesnot_exist(self.ref_config.value(ArjunaOption.REPORT_XML_DIR))
         self.__create_dir_if_doesnot_exist(self.ref_config.value(ArjunaOption.REPORT_HTML_DIR))
@@ -183,11 +255,21 @@ class ArjunaSingleton:
 
         deps_dir = get_deps_dir_path(self.ref_config.value(ArjunaOption.DEPS_DIR))
         if os.path.isdir(deps_dir):
-            sys.path.append(deps_dir)
+            sys.path.append(deps_dir) 
 
         # Load data references
-        from arjuna.engine.data.factory import DataReference
-        self.__contextual_data_references, self.__indexed_data_references  = DataReference.load_all(self.ref_config)
+        from arjuna.engine.data.factory import DataReference, DataReferences
+        self.__contextual_data_references = DataReferences()
+        self.__indexed_data_references = DataReferences()
+
+        for linked_project in self.__linked_projects:
+            cdrs, idrs = DataReference.load_all(linked_project.ref_conf)
+            self.__contextual_data_references.update(cdrs)
+            self.__indexed_data_references.update(idrs)
+
+        cdrs, idrs  = DataReference.load_all(self.ref_config)
+        self.__contextual_data_references.update(cdrs)
+        self.__indexed_data_references.update(idrs)
 
         # Load localization data
         from arjuna.engine.data.localizer import Localizer
@@ -206,6 +288,10 @@ class ArjunaSingleton:
 
         return self.ref_config
 
+    @property
+    def linked_projects(self):
+        return self.__linked_projects
+
     @property
     def test_wise_container(self):
         return self.__current_test_wise_objects
@@ -338,7 +424,7 @@ class Arjuna:
         return cls.__ARJ_COMMAND
 
     @classmethod
-    def init(cls, project_root_dir, cli_config=None, run_id=None, *, static_rid=False):
+    def init(cls, project_root_dir, cli_config=None, run_id=None, *, static_rid=False, linked_projects=[]):
         '''
             Returns reference test context which contains reference configuration.
             This reference test context merges central conf, project conf and central CLI options.
@@ -346,7 +432,9 @@ class Arjuna:
             You can also provide an alternative root directory for test project.
         '''
         cls.ARJUNA_SINGLETON = ArjunaSingleton()
-        return cls.ARJUNA_SINGLETON.init(project_root_dir, cli_config, run_id, static_rid=static_rid)
+        if linked_projects is None:
+            linked_projects = list()
+        return cls.ARJUNA_SINGLETON.init(project_root_dir, cli_config, run_id, static_rid=static_rid, linked_projects=linked_projects)
 
     @classmethod
     def get_logger(cls):
@@ -484,4 +572,8 @@ class Arjuna:
         '''
         proxy_server = cls._get_bmproxy_server()
         if proxy_server is not None:
-            proxy_server.stop()
\ No newline at end of file
+            proxy_server.stop()
+
+    @classmethod
+    def get_linked_projects(cls):
+        return cls.ARJUNA_SINGLETON.linked_projects
\ No newline at end of file
